@@ -1,3 +1,7 @@
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 # new function to fit different distributions
 # Authors Mikis Stasinopoulos and Vlasios Voudouris
 # TO DO
@@ -8,15 +12,16 @@
 # vi) output should be a matrix (OK)) with some functionality (see odrered function) 
 # v)  create new list for fitting all possible distribution with different 
 #    parametrizations (OK)
-#------------------------------------------------------------------------
-#------------------------------------------------------------------------
-#------------------------------------------------------------------------
-##########################################################################
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 # this grouping was checked on the 27-4-18
 #-------------------------------------------------------------------------------
 # the grouping of distributions
-#-------------------------------------------------------------------------------# this
-# Group of distribution with interval ranging from -infinity to +infinity
+################################################################################
+################################################################################
+# group of distribution with interval ranging from -infinity to +infinity
 .realline <- c( "NO", "GU", "RG" ,"LO", "NET",     # 2 par
                     "TF", "TF2", "PE","PE2", "SN1", "SN2", "exGAUS", # 3 par
                     "SHASH", "SHASHo","SHASHo2",                     # 4 par
@@ -24,40 +29,27 @@
                     "SEP1", "SEP2", "SEP3", "SEP4",                  # 4 par 
                     "ST1", "ST2", "ST3", "ST4", "ST5", "SST",        # 4 par 
                      "GT")  
-#--------------------------------------------------------------------------------
-#--------------------------------------------------------------------------------
+################################################################################
+################################################################################
 # Group of distribution with interval ranging from 0  to +infinity
 .realplus <- c( "EXP", # 1 par
                 "GA","IG","LOGNO", "LOGNO2","WEI", "WEI2", "WEI3", "IGAMMA",
                 "PARETO2", "PARETO2o", "GP", # 2 par
                 "BCCG", "BCCGo", "exGAUS", "GG", "GIG", "LNO",  # 3 par
                 "BCTo", "BCT", "BCPEo", "BCPE", "GB2")  # 4 par 
-#--------------------------------------------------------------------------------
-#--------------------------------------------------------------------------------
+################################################################################
+################################################################################
 # Group of distribution with interval ranging from 0 to 1
 .real0to1 <- c("BE", "BEo", # 2 par
                "BEINF0", "BEINF1", "LOGITNO", "SIMPLEX", #2 par 
                "BEOI", "BEZI", # 3 par
                "BEINF", # 4 par
                "GB1") # par
-
-#--------------------------------------------------------------------------------
-#--------------------------------------------------------------------------------
-# Group of distribution with interval ranging from -infinity to +infinity (.realline) or 0 to +infinity (.realplus)
+################################################################################
+################################################################################
 .realAll <- union(.realline, .realplus)
-# .realAllALL <- c( "EXP", # 1 par
-#                "GA","IG","LOGNO", "LOGNO2", "WEI", "WEI2", "WEI3", "IGAMMA",
-#                "PARETO2", "PARETO2o", "GP", # 2 par
-#                "BCCG", "BCCGo",  "GG", "GIG", "LNO",  # 3 par
-#                "BCTo", "BCT", "BCPEo", "BCPE", "GB2",
-#                "NO","GU", "RG" ,"LO", "NET", # 2 par
-#                "TF", "TF2", "PE", "PE2", "SN1", "SN2", "exGAUS",   # 3 par
-#                "SHASH", "SHASHo","SHASHo2", "EGB2", "JSU", "JSUo", 
-#                "SEP", "SEP1", "SEP2", "SEP3", "SEP4", "SEP", # 4 par
-#                "ST1", "ST2", "ST3", "ST3C", "ST4", "ST5", "SST", "GT")  # 4 par
-
-#--------------------------------------------------------------------------------               
-#--------------------------------------------------------------------------------
+################################################################################
+################################################################################    
 # Group of distribution for counting
 .counts <- c("PO", "GEOM", "GEOMo","LG", "YULE", "ZIPF", # 1 par
              "WARING", "GPO", "DPO", "BNB", "NBF",       # 
@@ -66,19 +58,20 @@
              "ZINBI",  "ZIPIG", "ZINBF",
              "ZABNB", "ZASICHEL", "ZINBF",  "ZIBNB", "ZISICHEL")
              
-#--------------------------------------------------------------------------------
+################################################################################
+################################################################################
 # Binomial group of distributions
 .binom <- c("BI",  # 1 par
             "BB", "DBI", "ZIBI", "ZABI", # 2 par
             "ZIBB", "ZABB")
-#-------------------------------------------------------------------------------------
-#-------------------------------------------------------------------------------------
-#-------------------------------------------------------------------------------------
-#-------------------------------------------------------------------------------------
-#-------------------------------------------------------------------------------------
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 chooseDist <- function(object,
-                       k = c(2, 3.84, round(log(length(object$y)),2)), # for the AIC
-                    type = c("realAll", "realline", "realplus","real0to1","counts", "binom", "extra" ), 
+                       k = c(2, 3.84, round(log(length(object$y)),2)),# for the AIC
+                    type = c("realAll", "realline", "realplus","real0to1",
+                             "counts", "binom", "extra" ), 
                    extra = NULL,  # for extra distributions to include 
                    trace = FALSE,
                 parallel = c("no", "multicore", "snow"), #
@@ -87,8 +80,8 @@ chooseDist <- function(object,
                        ...)
 {
   ## get the type of distribution  
-  type <- match.arg(type)
-  DIST <- switch(type, "realAll"= .realAll, 
+     type <- match.arg(type)
+     DIST <- switch(type, "realAll"= .realAll, 
                       "realline"= .realline, 
                       "realplus"= .realplus,
                       "real0to1"= .real0to1,
@@ -97,10 +90,9 @@ chooseDist <- function(object,
                          "extra"= extra)
   if (type=="extra"&&is.null(extra)) stop("extra is not set")
   if  (!is.null(extra)) DIST <- unique(c(DIST, extra))
-  ##   
        m0 <- object
   klength <- length(k)
-  AiC  <- rep(NA, klength) #matrix(NA, nrow=length(DIST), ncol= klength, dimnames=list(DIST,  as.character(k)))
+     AiC  <- rep(NA, klength) 
 #--------------- PARALLEL-------------------------------------------------------
 #----------------SET UP PART----------------------------------------------------
     parallel <- match.arg(parallel)
@@ -129,12 +121,10 @@ fun <- function(dist,...)
       for (j in 1:klength) AiC[j] <- AIC(m1, k=k[j])
       if (trace)     cat(dist, "\n",AiC, "\n")
     }
-    c(AiC)        # autput of the function
+    c(AiC)        # Output of the function
   }
-#----------------------------------------------------------------    
-#----------------------------------------------------------------
-#----------------------------------------------------------------
-# --------  parallel --------------------------------------------
+################################################################################    
+# --------  parallel -----------------------------------------------------------
   MM <- if (ncpus > 1L && (have_mc || have_snow)) 
      {
        if (have_mc) 
@@ -157,7 +147,7 @@ fun <- function(dist,...)
              if (RNGkind()[1L] == "L'Ecuyer-CMRG") 
                  parallel::clusterSetRNGStream(cl)
              res <-  matrix(unlist((parallel::parLapply(cl, DIST, fun))),
-                                  ncol=klength, byrow = T, 
+                       ncol=klength, byrow = T, 
                             dimnames = list(DIST,  as.character(k))) 
              parallel::stopCluster(cl)
              res
@@ -167,14 +157,16 @@ fun <- function(dist,...)
       }# end parallel -----
      else  matrix(sapply(DIST, fun, ...), ncol=klength, byrow = T, 
                     dimnames = list(DIST,  as.character(k)))  
-#----------------------------------------------------------------  
-#----------------------------------------------------------------    
+#-------------------------------------------------------------------------------  
      for (i in 1:length(k)) cat("minimum GAIC(k=",k[i],") family:", 
                                 names(which.min(MM[,i])), "\n")
-#----------------------------------------------------------------
+#-------------------------------------------------------------------------------
      MM  
 }
-#----------------------------------------------------------------
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 getOrder <- function(obj, column=1) 
 {
   if (!is.matrix(obj)) stop("the object should be a matrix")
@@ -183,9 +175,10 @@ getOrder <- function(obj, column=1)
   cat("GAIG with k=", name, "\n" )
   out 
 }
- 
-#--------------------------------------------------------------------------------------
-#--------------------------------------------------------------------------------------
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 # chooseDistPred <- function(object,
 #                            newdata = NULL,  
 #                               rand = NULL,
@@ -245,38 +238,41 @@ getOrder <- function(obj, column=1)
 # #--------------------------------------------------------------------------------------
 # #--------------------------------------------------------------------------------------
 #--------------------------------------------------------------------------------------
-#--------------------------------------------------------------------------------------
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 chooseDistPred <- function(object,
-                           type = c("realAll", "realline", "realplus","real0to1","counts", "binom", "extra" ), 
-                           extra = NULL,  # for extra distributions to include 
-                           trace = FALSE,
-                           parallel = c("no", "multicore", "snow"), #
-                           ncpus = 1L, #integer: number of processes to be used in parallel operation: typically one would chose this to the number of available CPUs
-                           cl = NULL, # An optional parallel or snow cluster for use if parallel = "snow". If not supplied, a cluster on t     
-                           newdata = NULL,
-                           rand = NULL,
+                  type = c("realAll", "realline", "realplus","real0to1",
+                           "counts", "binom", "extra" ), 
+                 extra = NULL,  # for extra distributions to include 
+                 trace = FALSE,
+              parallel = c("no", "multicore", "snow"), #
+                 ncpus = 1L, #integer: number of processes to be used in parallel operation: typically one would chose this to the number of available CPUs
+                    cl = NULL, # An optional parallel or snow cluster for use if parallel = "snow". If not supplied, a cluster on t     
+               newdata = NULL,
+                  rand = NULL,
                            ...)
 {
-  ## get the type of distribution
-  newData <- if(is.null(newdata)) FALSE else TRUE
-  type <- match.arg(type)
-  if (is.null(rand)&&is.null(newdata)) stop("rand or newdata should be set")
-  if (!is.null(rand)&&!is.null(newdata)) stop("only rand or newdata should be set NOT both")
-  DIST <- switch(type, "realAll"=.realAll,
+## get the type of distribution
+    newData <- if(is.null(newdata)) FALSE else TRUE
+       type <- match.arg(type)
+if (is.null(rand)&&is.null(newdata)) stop("rand or newdata should be set")
+if (!is.null(rand)&&!is.null(newdata)) stop("only rand or newdata should be set NOT both")
+     DIST <- switch(type, "realAll"=.realAll,
                  "realline"=.realline,
                  "realplus"=.realplus,
                  "real0to1"=.real0to1,
                  "counts"=.counts,
                  "binom"=.binom,
                  "extra"= extra)
-  if (type=="extra"&&is.null(extra)) stop("extra is not set")
-  if  (!is.null(extra)) DIST <- unique(c(DIST, extra))
-  ##
-  m0 <- object
-  tgd0 <- getTGD(m0, newdata=newdata)
-  AiC  <- rep(NA, 1)
-  #--------------- PARALLEL-------------------------------------------------------
-  #----------------SET UP PART----------------------------------------------------
+if (type=="extra"&&is.null(extra)) stop("extra is not set")
+if  (!is.null(extra)) DIST <- unique(c(DIST, extra))
+     m0 <- object
+   tgd0 <- getTGD(m0, newdata=newdata)
+   AiC  <- rep(NA, 1)
+  #--------------- PARALLEL-----------------------------------------------------
+  #----------------SET UP PART--------------------------------------------------
   parallel <- match.arg(parallel)
   have_mc <- have_snow <- FALSE
   if (parallel != "no" && ncpus > 1L) 
@@ -289,10 +285,11 @@ chooseDistPred <- function(object,
       ncpus <- 1L
     loadNamespace("parallel")
   } 
-  # -------------- finish parallel------------------------------------------------     
-  # define the function
+  # -------------- finish parallel----------------------------------------------     
+# define the function
   fun <- function(dist)
   {
+ # cat(dist, "\n")
     m1 <- try(update(object,family=dist, trace=FALSE,...), silent=TRUE)
     if (any(class(m1)%in%"try-error"))
     {
@@ -300,7 +297,7 @@ chooseDistPred <- function(object,
     }
     else
     {
-      tgd1 <- getTGD(m1, newdata=newdata)
+      tgd1 <- getTGD(m1, newdata=newdata )
       if (trace)     cat(dist, "\n", tgd1$TGD, "\n")
       AiC <- tgd1$TGD
       # if (TGD(tgd1) < TGD(tgd0))
@@ -310,10 +307,8 @@ chooseDistPred <- function(object,
     }
     c(AiC)        # autput of the function
   }
-  #----------------------------------------------------------------    
-  #----------------------------------------------------------------
-  #----------------------------------------------------------------
-  # --------  parallel --------------------------------------------
+################################################################################ 
+# --------  parallel -----------------------------------------------------------
   MM <- if (ncpus > 1L && (have_mc || have_snow)) 
   {
     if (have_mc) 
@@ -341,17 +336,17 @@ chooseDistPred <- function(object,
       else parallel::parLapply(cl, DIST, fun)# use existing cluster
     }
   }# end parallel -----
-  else  sapply(DIST, fun) 
-  #----------------------------------------------------------------  
-  #----------------------------------------------------------------         
-  names(MM) <- DIST
-  #----------------------------------------------------------------
+  else sapply(DIST, fun, ...) 
+#-------------------------------------------------------------------------------  
+   names(MM) <- DIST
+#-------------------------------------------------------------------------------
   ## save it in the final model
   #m0$TGD <- MM[order(MM)]
-  #----------------------------------------------------------------
-  #----------------------------------------------------------------
   MM[order(MM)]
 }
-#--------------------------------------------------------------------------------------
-#--------------------------------------------------------------------------------------
+################################################################################
+################################################################################
+################################################################################
+################################################################################
+
 
